@@ -109,9 +109,9 @@ class Executor(object):
         elif len(action) == 1:
             return event()
         else:
-            raise WebRunnerExecuteException(executor_data_error)
+            raise WebRunnerExecuteException(executor_data_error + " " + str(action))
 
-    def execute_action(self, action_list: list) -> Tuple[str, list]:
+    def execute_action(self, action_list: [list, dict]) -> dict:
         """
         :param action_list: like this structure
         [
@@ -120,8 +120,11 @@ class Executor(object):
         for loop and use execute_event function to execute
         :return: recode string, response as list
         """
-        execute_record_string = ""
-        event_response_list = []
+        if type(action_list) is dict:
+            action_list = action_list.get("web_runner", None)
+            if action_list is None:
+                raise WebRunnerExecuteException(executor_list_error)
+        execute_record_dict = dict()
         try:
             if len(action_list) > 0 or type(action_list) is not list:
                 pass
@@ -132,12 +135,15 @@ class Executor(object):
         for action in action_list:
             try:
                 event_response = self._execute_event(action)
-                print("execute: ", str(action))
-                execute_record_string = "".join(execute_record_string)
-                event_response_list.append(event_response)
+                execute_record = "execute: " + str(action)
+                execute_record_dict.update({execute_record: event_response})
             except Exception as error:
                 print(repr(error), file=sys.stderr)
-        return execute_record_string, event_response_list
+                print(action, file=sys.stderr)
+        for key, value in execute_record_dict.items():
+            print(key)
+            print(value)
+        return execute_record_dict
 
     def execute_files(self, execute_files_list: list) -> list:
         """
@@ -161,7 +167,7 @@ def add_command_to_executor(command_dict: dict):
             raise WebRunnerAddCommandException(add_command_exception_tag)
 
 
-def execute_action(action_list: list) -> Tuple[str, list]:
+def execute_action(action_list: list) -> dict:
     return executor.execute_action(action_list)
 
 
